;;;;
;;;; converter.lisp
;;;;
;;;; George Ferguson, ferguson@cs.rochester.edu,  4 Sep 2002
;;;; Time-stamp: <Thu Sep  5 16:42:34 EDT 2002 ferguson>
;;;;
;;;; Convert a file of defaxiom forms such as produced by hobbs2lisp.
;;;; See README.txt or Makefile for the steps involved.
;;;;

(load "lisp2triples" :verbose nil)
(load "triples2daml" :verbose nil)

(defun lisp2triples ()
  "Translate lisp forms read on *standard-input* into sets of triples
by calling Trtop on them, and print the result in a Lisp-y format to
*standard-output*."
  (format t "~%;; lisp2triples: ~A~%~%" (timestamp))
  (loop with form
      for i from 1
      while (setq form (read *standard-input* nil nil))
      do (let ((tag (second form))
	       (expr (third form))
	       (q (list i)))
	   (format t "~S~%~%" (list 'triples tag
				    (second (multiple-value-list (Trtop expr q))))))))

(defun triples2daml ()
  "Translate sets of triples read on *standard-input* into XML/DAML
markup entities, and print them to *standard-output*."
  (format t "~%<!-- triples2daml: ~A -->~%~%" (timestamp))
  (loop with form
      while (setq form (read *standard-input* nil nil))
      do (let* ((tag (second form))
		(triples (third form))
		(entity (first (xmlify triples))))
	   (setf (slot-value entity 'id) tag)
	   (print-object entity t)
	   (terpri)))
  (format t "~%<!-- ~A: -->~%" "Local Variables")
  (format t "<!-- mode: xml -->~%")
  (format t "<!-- ~A: -->~%" "End"))

(defun timestamp ()
  "Returns an timestamp in standard unix ctime() format."
  (flet ((downame (n) (elt '("Mon" "Tue" "Wed" "Thu" "Fri" "Sat" "Sun") n))
	 (monthname (n) (elt '("" "Jan" "Feb" "Mar" "Apr" "May" "Jun"
			       "Jul" "Aug" "Sep" "Oct" "Nov" "Dec") n))
	 (tzname (n dstp) (case n
			   (5 (if dstp "EDT" "EST"))
			   (6 (if dstp "CDT" "CST"))
			   (7 (if dstp "MDT" "MST"))
			   (8 (if dstp "PDT" "PST"))
			   (t (format nil "GMT~@D~@[DST~]" n dstp)))))
    (multiple-value-bind (sec min hour date month year dow dstp tz)
	(get-decoded-time)
      (format nil "~3A ~3A ~2D ~2D:~2,'0D:~2,'0D ~A ~4D"
	      (downame dow) (monthname month) date hour min sec
	      (tzname tz dstp) year))))
